/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#include "Heavy_WSTD_DLAY.hpp"

#include <new>

#define Context(_c) static_cast<Heavy_WSTD_DLAY *>(_c)


/*
 * C Functions
 */

extern "C" {
  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new(double sampleRate) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate);
    return Context(ptr);
  }

  HV_EXPORT HeavyContextInterface *hv_WSTD_DLAY_new_with_options(double sampleRate,
      int poolKb, int inQueueKb, int outQueueKb) {
    // allocate aligned memory
    void *ptr = hv_malloc(sizeof(Heavy_WSTD_DLAY));
    // ensure non-null
    if (!ptr) return nullptr;
    // call constructor
    new(ptr) Heavy_WSTD_DLAY(sampleRate, poolKb, inQueueKb, outQueueKb);
    return Context(ptr);
  }

  HV_EXPORT void hv_WSTD_DLAY_free(HeavyContextInterface *instance) {
    // call destructor
    Context(instance)->~Heavy_WSTD_DLAY();
    // free memory
    hv_free(instance);
  }
} // extern "C"







/*
 * Class Functions
 */

Heavy_WSTD_DLAY::Heavy_WSTD_DLAY(double sampleRate, int poolKb, int inQueueKb, int outQueueKb)
    : HeavyContext(sampleRate, poolKb, inQueueKb, outQueueKb) {
  numBytes += sLine_init(&sLine_OnPWhkR2);
  numBytes += sLine_init(&sLine_Oq7NfQBN);
  numBytes += sTabhead_init(&sTabhead_CoGLviVA, &hTable_buq1Ber6);
  numBytes += sTabread_init(&sTabread_9aaYFynR, &hTable_buq1Ber6, false);
  numBytes += sTabread_init(&sTabread_q3oyyX6w, &hTable_buq1Ber6, false);
  numBytes += sLine_init(&sLine_ySN3MIY0);
  numBytes += sLine_init(&sLine_aWK9v4wZ);
  numBytes += sLine_init(&sLine_RqvnsIAI);
  numBytes += sTabhead_init(&sTabhead_Iq6c7vjK, &hTable_wBMkSMgR);
  numBytes += sTabread_init(&sTabread_tuvlnPZU, &hTable_wBMkSMgR, false);
  numBytes += sTabread_init(&sTabread_FVyPzYH4, &hTable_wBMkSMgR, false);
  numBytes += sLine_init(&sLine_Wusx0DzF);
  numBytes += sTabwrite_init(&sTabwrite_fkpWOmCs, &hTable_buq1Ber6);
  numBytes += sTabwrite_init(&sTabwrite_09m8jtok, &hTable_wBMkSMgR);
  numBytes += sRPole_init(&sRPole_8Nnfwqd6);
  numBytes += sRPole_init(&sRPole_gS2ZP55h);
  numBytes += sRPole_init(&sRPole_VASGJz3P);
  numBytes += sDel1_init(&sDel1_agxH38lZ);
  numBytes += sLine_init(&sLine_QUG5OGwO);
  numBytes += sLine_init(&sLine_fbYsDjOX);
  numBytes += sRPole_init(&sRPole_kF56a4OO);
  numBytes += sRPole_init(&sRPole_XMYk4rv5);
  numBytes += sRPole_init(&sRPole_INoGnglR);
  numBytes += sDel1_init(&sDel1_7j0Af9V5);
  numBytes += sLine_init(&sLine_lK5HD1uP);
  numBytes += sLine_init(&sLine_6VHhC3AB);
  numBytes += sLine_init(&sLine_QphoXbAb);
  numBytes += sLine_init(&sLine_Dc1lraeP);
  numBytes += cVar_init_f(&cVar_9Oc4gaK3, 0.0f);
  numBytes += cVar_init_f(&cVar_rSe2n52Z, 0.0f);
  numBytes += cVar_init_f(&cVar_rK1VHM16, 0.0f);
  numBytes += cVar_init_f(&cVar_KgPXFbDE, 0.0f);
  numBytes += cSlice_init(&cSlice_Ij33VXLR, 1, -1);
  numBytes += cVar_init_f(&cVar_l7ZkfGY6, 0.5f);
  numBytes += cSlice_init(&cSlice_3vZQKk3t, 1, -1);
  numBytes += cVar_init_f(&cVar_nd6uL5Fh, 0.2f);
  numBytes += cSlice_init(&cSlice_7ngxj1t9, 1, -1);
  numBytes += cVar_init_f(&cVar_Xq6N6KVs, 500.0f);
  numBytes += cSlice_init(&cSlice_DTPhuiSG, 1, -1);
  numBytes += cVar_init_f(&cVar_03BwVQVy, 0.25f);
  numBytes += cDelay_init(this, &cDelay_mbVzZfOc, 0.0f);
  numBytes += cDelay_init(this, &cDelay_GTnphr4x, 0.0f);
  numBytes += hTable_init(&hTable_buq1Ber6, 256);
  numBytes += cDelay_init(this, &cDelay_aXpJ3ceg, 0.0f);
  numBytes += cDelay_init(this, &cDelay_wiCZR0mh, 0.0f);
  numBytes += hTable_init(&hTable_wBMkSMgR, 256);
  numBytes += cVar_init_f(&cVar_3wxlOZ8w, 8000.0f);
  numBytes += cBinop_init(&cBinop_LBRz6R66, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_4SlWMGHh, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_etRbVuuc, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_Kc9DHmmL, 8000.0f);
  numBytes += cBinop_init(&cBinop_PQlXqOPf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_eRruzhGI, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_UXwHHZR9, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_tRAndOq8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_1vGLPieS, 300.0f);
  numBytes += cBinop_init(&cBinop_dvY2fbfU, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_2Wod2iJR, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_UNrpeEcJ, "del-1011-delayL");
  numBytes += sVarf_init(&sVarf_bxUwvGRm, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_SNZSPAjg, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_CbiieDnN, 0.0f, 0.0f, false);
  numBytes += cVar_init_s(&cVar_tgfwhqpu, "del-1011-delayR");
  numBytes += sVarf_init(&sVarf_wyPSfn3h, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Qm0kjqfM, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_bpjiHenw, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_EkdYf1OI, 8000.0f);
  numBytes += cBinop_init(&cBinop_c73N9gwi, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_fm9B44YS, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_iYOgGUV8, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_spS7S1gQ, 8000.0f);
  numBytes += cBinop_init(&cBinop_63IH9owf, 0.0f); // __mul
  numBytes += sVarf_init(&sVarf_Mq5Dqw53, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_Szm0R5ep, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_WYAoUNxZ, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_bNYo9qlk, 300.0f);
  numBytes += cBinop_init(&cBinop_8qIJ5wJf, 0.0f); // __div
  numBytes += sVarf_init(&sVarf_Q9AgGE2Y, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_vL7A4YK4, 0.0f, 0.0f, false);
  numBytes += sVarf_init(&sVarf_J5qzPAbM, 0.0f, 0.0f, false);
  numBytes += cVar_init_f(&cVar_uQqYvqn9, 1.0f);
  numBytes += cIf_init(&cIf_TOtK2D17, false);
  numBytes += cIf_init(&cIf_hbZvpCMt, false);
  numBytes += cVar_init_f(&cVar_Q4wGuM7q, 0.0f);
  numBytes += cVar_init_f(&cVar_IpFIC0eE, 0.0f);
  numBytes += cVar_init_f(&cVar_Nxo8MWfo, 60000.0f);
  numBytes += cVar_init_f(&cVar_Gl7Hq3Xr, 500.0f);
  numBytes += cSlice_init(&cSlice_7i4VcadT, 1, -1);
  numBytes += cSlice_init(&cSlice_XoLpHKMB, 1, -1);
  numBytes += cVar_init_f(&cVar_oWX7rJOV, 0.0f);
  numBytes += cIf_init(&cIf_h05RrBQl, false);
  numBytes += cBinop_init(&cBinop_aUW9f4wJ, 0.0f); // __neq
  numBytes += cVar_init_f(&cVar_X1j4Duy2, 120.0f);
  numBytes += cBinop_init(&cBinop_jKgTl8X0, 0.0f); // __div
  numBytes += cBinop_init(&cBinop_AVPSljh0, 0.0f); // __mul
  
  // schedule a message to trigger all loadbangs via the __hv_init receiver
  scheduleMessageForReceiver(0xCE5CC65B, msg_initWithBang(HV_MESSAGE_ON_STACK(1), 0));
}

Heavy_WSTD_DLAY::~Heavy_WSTD_DLAY() {
  hTable_free(&hTable_buq1Ber6);
  hTable_free(&hTable_wBMkSMgR);
}

HvTable *Heavy_WSTD_DLAY::getTableForHash(hv_uint32_t tableHash) {switch (tableHash) {
    case 0x33B09DD4: return &hTable_buq1Ber6; // del-1011-delayL
    case 0xF057CB49: return &hTable_wBMkSMgR; // del-1011-delayR
    default: return nullptr;
  }
}

void Heavy_WSTD_DLAY::scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) {
  switch (receiverHash) {
    case 0xB6A8F09D: { // Cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_oE5fEXKS_sendMessage);
      break;
    }
    case 0x57157946: { // Feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_9ffXVyp7_sendMessage);
      break;
    }
    case 0x97D46AC6: { // Mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_XG0WzVy1_sendMessage);
      break;
    }
    case 0x4A331B66: { // Sync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_vchNECxJ_sendMessage);
      break;
    }
    case 0x58E5C2DB: { // Time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_yqUiqYLH_sendMessage);
      break;
    }
    case 0x49107604: { // TimeSync
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_xyol7U4O_sendMessage);
      break;
    }
    case 0xD640D30E: { // 1011-cross
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_V6AktjDv_sendMessage);
      break;
    }
    case 0xC82F3AD1: { // 1011-feedback
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_SfhjSkND_sendMessage);
      break;
    }
    case 0x6E7C47FF: { // 1011-mix
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_3DS2kO22_sendMessage);
      break;
    }
    case 0xD896CBA3: { // 1011-time
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_o1foEvXv_sendMessage);
      break;
    }
    case 0xDF8C2721: { // __hv_dpf_bpm
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_4zhuenLS_sendMessage);
      break;
    }
    case 0xCE5CC65B: { // __hv_init
      mq_addMessageByTimestamp(&mq, m, 0, &cReceive_BdJB8Rkb_sendMessage);
      break;
    }
    default: return;
  }
}

int Heavy_WSTD_DLAY::getParameterInfo(int index, HvParameterInfo *info) {
  if (info != nullptr) {
    switch (index) {
      case 0: {
        info->name = "Cross";
        info->hash = 0xB6A8F09D;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 20.0f;
        break;
      }
      case 1: {
        info->name = "Feedback";
        info->hash = 0x57157946;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 25.0f;
        break;
      }
      case 2: {
        info->name = "Mix";
        info->hash = 0x97D46AC6;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 100.0f;
        info->defaultVal = 50.0f;
        break;
      }
      case 3: {
        info->name = "Sync";
        info->hash = 0x4A331B66;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 1.0f;
        info->defaultVal = 0.0f;
        break;
      }
      case 4: {
        info->name = "Time";
        info->hash = 0x58E5C2DB;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 50.0f;
        info->maxVal = 5000.0f;
        info->defaultVal = 500.0f;
        break;
      }
      case 5: {
        info->name = "TimeSync";
        info->hash = 0x49107604;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 12.0f;
        info->defaultVal = 6.0f;
        break;
      }
      default: {
        info->name = "invalid parameter index";
        info->hash = 0;
        info->type = HvParameterType::HV_PARAM_TYPE_PARAMETER_IN;
        info->minVal = 0.0f;
        info->maxVal = 0.0f;
        info->defaultVal = 0.0f;
        break;
      }
    }
  }
  return 6;
}



/*
 * Send Function Implementations
 */


void Heavy_WSTD_DLAY::cVar_9Oc4gaK3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_D30otQYn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_rSe2n52Z_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GVpcAM3N_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_rK1VHM16_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4QLoZ8F6_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cVar_KgPXFbDE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_rW9JdECd_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_lKO7Wwx0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x764F1C36: { // "mix"
      cSlice_onMessage(_c, &Context(_c)->cSlice_Ij33VXLR, 0, m, &cSlice_Ij33VXLR_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_Ij33VXLR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_NnimxFmG_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_NnimxFmG_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_l7ZkfGY6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_NnimxFmG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_NnimxFmG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_3DS2kO22_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_mRJJCoQW_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xC8CCFEC1: { // "cross"
      cSlice_onMessage(_c, &Context(_c)->cSlice_3vZQKk3t, 0, m, &cSlice_3vZQKk3t_sendMessage);
      break;
    }
    default: {
      cSwitchcase_nwg9lQT0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_3vZQKk3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_VoRo4zn1_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_VoRo4zn1_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_nd6uL5Fh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_VoRo4zn1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_VoRo4zn1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_V6AktjDv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_LvCPiCRs_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x8E55AA5F: { // "time"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7ngxj1t9, 0, m, &cSlice_7ngxj1t9_sendMessage);
      break;
    }
    default: {
      cSwitchcase_lKO7Wwx0_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_7ngxj1t9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_DkVLW8yJ_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_DkVLW8yJ_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_Xq6N6KVs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_DkVLW8yJ_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_DkVLW8yJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_o1foEvXv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_RBy2HeNM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Fy3Gyl5K_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Fy3Gyl5K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_ztoA4kyI_sendMessage);
}

void Heavy_WSTD_DLAY::cUnop_crsI9S8f_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lVCYQPBV_sendMessage(_c, 0, m);
  cMsg_7mxcJzv1_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cUnop_yT56nFIR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_dxG6eRFP_sendMessage(_c, 0, m);
  cMsg_z1v06OoX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ztoA4kyI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_U1PgqJQT_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_U1PgqJQT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_IZQGflmf_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_JNOSKu43_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_JNOSKu43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_j0q2lH8V_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_IZQGflmf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_1Nz11jFo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_1Nz11jFo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_xohA3M4y_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_j0q2lH8V_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_8R5DjZuu_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8R5DjZuu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_X38WNLb4_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_xohA3M4y_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_crsI9S8f_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_X38WNLb4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cUnop_onMessage(_c, HV_UNOP_SQRT, m, &cUnop_yT56nFIR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_CnjBQmU5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_AwrTFmMb_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_AwrTFmMb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 2.0f, 0, m, &cBinop_Gjkb3VFn_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Gjkb3VFn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_p83e03x8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_p83e03x8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_pB1qtLX1_sendMessage);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HbmJ6rAZ_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_pB1qtLX1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_ivN6H75G_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_HbmJ6rAZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_9gp5gcXP_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_ivN6H75G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_JaHuFp4K_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_9gp5gcXP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_rsd7M6WK_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rsd7M6WK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_G1lKuHFU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_G1lKuHFU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PdI1pyAj_sendMessage(_c, 0, m);
  cMsg_vyLzZ4px_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_JaHuFp4K_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gUfYDEvR_sendMessage(_c, 0, m);
  cMsg_9x4ghFxU_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_nwg9lQT0_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xF1E7CD16: { // "feedback"
      cSlice_onMessage(_c, &Context(_c)->cSlice_DTPhuiSG, 0, m, &cSlice_DTPhuiSG_sendMessage);
      break;
    }
    default: {
      cSwitchcase_LvCPiCRs_onMessage(_c, NULL, 0, m, NULL);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_DTPhuiSG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cSend_cRJ3Hg0l_sendMessage(_c, 0, m);
      break;
    }
    case 1: {
      cSend_cRJ3Hg0l_sendMessage(_c, 0, m);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_03BwVQVy_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSend_cRJ3Hg0l_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSend_cRJ3Hg0l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cReceive_SfhjSkND_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_1z0fnGOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_z5W9IHC3_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_z5W9IHC3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_Uc2s5Zy7_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_mbVzZfOc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_mbVzZfOc, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_GTnphr4x, 0, m, &cDelay_GTnphr4x_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mbVzZfOc, 0, m, &cDelay_mbVzZfOc_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fkpWOmCs, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_GTnphr4x_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_GTnphr4x, m);
  cMsg_QbEit9Rm_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_AQCqFuMj_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_yIc9cE1t_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_zDH6sKOW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_QLZnZtoE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_buq1Ber6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lO6qk57E_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_mbVzZfOc, 2, m, &cDelay_mbVzZfOc_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_TF943sV4_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_QLZnZtoE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_buq1Ber6, 0, m, &hTable_buq1Ber6_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Uc2s5Zy7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_zDH6sKOW_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_QbEit9Rm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_buq1Ber6, 0, m, &hTable_buq1Ber6_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_TF943sV4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_mbVzZfOc, 0, m, &cDelay_mbVzZfOc_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_lO6qk57E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_GTnphr4x, 2, m, &cDelay_GTnphr4x_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_yIc9cE1t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_fkpWOmCs, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_084tj0Aq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_CIdyjMs9_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_CIdyjMs9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_ypozcDiT_sendMessage);
}

void Heavy_WSTD_DLAY::cDelay_aXpJ3ceg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_aXpJ3ceg, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_wiCZR0mh, 0, m, &cDelay_wiCZR0mh_sendMessage);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aXpJ3ceg, 0, m, &cDelay_aXpJ3ceg_sendMessage);
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_09m8jtok, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cDelay_wiCZR0mh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const m) {
  cDelay_clearExecutingMessage(&Context(_c)->cDelay_wiCZR0mh, m);
  cMsg_fc7LRjwl_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSwitchcase_b5XZeBiD_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x47BE8354: { // "clear"
      cMsg_bpSIyEim_sendMessage(_c, 0, m);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cBinop_MaOMk6vf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_urzBZG9k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::hTable_wBMkSMgR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ngxJeCTM_sendMessage(_c, 0, m);
  cDelay_onMessage(_c, &Context(_c)->cDelay_aXpJ3ceg, 2, m, &cDelay_aXpJ3ceg_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_ysWToE8Q_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_urzBZG9k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "resize");
  msg_setElementToFrom(m, 1, n, 0);
  hTable_onMessage(_c, &Context(_c)->hTable_wBMkSMgR, 0, m, &hTable_wBMkSMgR_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_ypozcDiT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 5000.0f, 0, m, &cBinop_MaOMk6vf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fc7LRjwl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mirror");
  hTable_onMessage(_c, &Context(_c)->hTable_wBMkSMgR, 0, m, &hTable_wBMkSMgR_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_ysWToE8Q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cDelay_onMessage(_c, &Context(_c)->cDelay_aXpJ3ceg, 0, m, &cDelay_aXpJ3ceg_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ngxJeCTM_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0,  static_cast<float>(HV_N_SIMD));
  cDelay_onMessage(_c, &Context(_c)->cDelay_wiCZR0mh, 2, m, &cDelay_wiCZR0mh_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_bpSIyEim_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "clear");
  sTabwrite_onMessage(_c, &Context(_c)->sTabwrite_09m8jtok, 1, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_3wxlOZ8w_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LBRz6R66, HV_BINOP_MULTIPLY, 0, m, &cBinop_LBRz6R66_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_LMoRpsrY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ZeDYURi7_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_ZeDYURi7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_PpDyqVSe_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_LBRz6R66_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_qZvrm8Q8_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_oQ19GAGB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_LBRz6R66, HV_BINOP_MULTIPLY, 1, m, &cBinop_LBRz6R66_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_PpDyqVSe_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_oQ19GAGB_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_qZvrm8Q8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_z8FsJUo3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_z8FsJUo3_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_3Iy4SIw7_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_etRbVuuc, m);
}

void Heavy_WSTD_DLAY::cBinop_3Iy4SIw7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_4SlWMGHh, m);
}

void Heavy_WSTD_DLAY::cVar_Kc9DHmmL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PQlXqOPf, HV_BINOP_MULTIPLY, 0, m, &cBinop_PQlXqOPf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_SfGHl584_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_waz12ZVj_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_waz12ZVj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_S8eSPrEC_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_PQlXqOPf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_NePOLU3t_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_f5E30R6r_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_PQlXqOPf, HV_BINOP_MULTIPLY, 1, m, &cBinop_PQlXqOPf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_S8eSPrEC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_f5E30R6r_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_NePOLU3t_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_Yj1DgXot_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Yj1DgXot_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_PSRCfXIQ_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_UXwHHZR9, m);
}

void Heavy_WSTD_DLAY::cBinop_PSRCfXIQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_eRruzhGI, m);
}

void Heavy_WSTD_DLAY::cBinop_myxnBcVn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_4MnELsFL_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_4MnELsFL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_DKpxkSXm_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_L9yeBYom_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_1vGLPieS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_GlgMo1to_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Im8Xyj6G_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_ucSL0xsr_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_ucSL0xsr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dvY2fbfU, HV_BINOP_DIVIDE, 1, m, &cBinop_dvY2fbfU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_DKpxkSXm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_3NOEV9r7_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_3NOEV9r7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_2Wod2iJR, m);
}

void Heavy_WSTD_DLAY::cMsg_bwA4Io7L_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_yKXOHcaX_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yKXOHcaX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_myxnBcVn_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_L9yeBYom_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_tRAndOq8, m);
}

void Heavy_WSTD_DLAY::cBinop_GlgMo1to_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_Cm5HgORg_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Cm5HgORg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_dvY2fbfU, HV_BINOP_DIVIDE, 0, m, &cBinop_dvY2fbfU_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_dvY2fbfU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_bwA4Io7L_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_r0BCw8tc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_JrW6jH6N_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_JrW6jH6N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_KQ4NIcAH_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_UNrpeEcJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_gOg6DbOE_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_wpJlubCa_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_0u8jtJ3E_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_bxUwvGRm, m);
}

void Heavy_WSTD_DLAY::cBinop_KQ4NIcAH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_SNZSPAjg, m);
}

void Heavy_WSTD_DLAY::cMsg_gOg6DbOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_wpJlubCa_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0u8jtJ3E_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_CbiieDnN, m);
}

void Heavy_WSTD_DLAY::cMsg_Xuqewkds_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_06wR5t9o_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_06wR5t9o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 1000.0f, 0, m, &cBinop_eHWHAjtd_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_tgfwhqpu_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_xguWEKgG_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cSystem_aWbGIQwY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_r1TMIPTV_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_wyPSfn3h, m);
}

void Heavy_WSTD_DLAY::cBinop_eHWHAjtd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Qm0kjqfM, m);
}

void Heavy_WSTD_DLAY::cMsg_xguWEKgG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(3);
  msg_init(m, 3, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "table");
  msg_setElementToFrom(m, 1, n, 0);
  msg_setSymbol(m, 2, "size");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_aWbGIQwY_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_r1TMIPTV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_bpjiHenw, m);
}

void Heavy_WSTD_DLAY::cVar_EkdYf1OI_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c73N9gwi, HV_BINOP_MULTIPLY, 0, m, &cBinop_c73N9gwi_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IpcRjbHw_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_5DGUP1pr_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_5DGUP1pr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_lLkJ9qrK_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_c73N9gwi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_KPaUgHxV_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_bWlBU3ns_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_c73N9gwi, HV_BINOP_MULTIPLY, 1, m, &cBinop_c73N9gwi_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_lLkJ9qrK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_bWlBU3ns_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_KPaUgHxV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_tAKK1CEs_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_tAKK1CEs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_ZKBCBKEk_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_iYOgGUV8, m);
}

void Heavy_WSTD_DLAY::cBinop_ZKBCBKEk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_fm9B44YS, m);
}

void Heavy_WSTD_DLAY::cVar_spS7S1gQ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_63IH9owf, HV_BINOP_MULTIPLY, 0, m, &cBinop_63IH9owf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_IWOeE88A_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_fOylxyMN_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_fOylxyMN_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_nRC6VO7o_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_63IH9owf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_9ZyUwTdd_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_JYXYuVET_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_63IH9owf, HV_BINOP_MULTIPLY, 1, m, &cBinop_63IH9owf_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_nRC6VO7o_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.28319f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 0.0f, 0, m, &cBinop_JYXYuVET_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9ZyUwTdd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_LOKOg4RD_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_LOKOg4RD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 1.0f, 0, m, &cBinop_NLYKuUnY_sendMessage);
  sVarf_onMessage(_c, &Context(_c)->sVarf_Szm0R5ep, m);
}

void Heavy_WSTD_DLAY::cBinop_NLYKuUnY_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Mq5Dqw53, m);
}

void Heavy_WSTD_DLAY::cBinop_Zv9NZc8J_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 0.0f, 0, m, &cBinop_yEOEzTxH_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_yEOEzTxH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_ADD, 1.0f, 0, m, &cBinop_0DFXpBMX_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, -1.0f, 0, m, &cBinop_9lY1MYXo_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_bNYo9qlk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MAX, 1.0f, 0, m, &cBinop_qfMccuvj_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_Q6Cbq8qq_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "samplerate");
  cSystem_onMessage(_c, NULL, 0, m, &cSystem_3tDMWDOE_sendMessage);
}

void Heavy_WSTD_DLAY::cSystem_3tDMWDOE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8qIJ5wJf, HV_BINOP_DIVIDE, 1, m, &cBinop_8qIJ5wJf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_0DFXpBMX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 0.5f, 0, m, &cBinop_rZZcS90l_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_rZZcS90l_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_Q9AgGE2Y, m);
}

void Heavy_WSTD_DLAY::cMsg_h656UThi_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  msg_setElementToFrom(m, 1, n, 0);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_SUBTRACT, 0.0f, 0, m, &cBinop_Wf96RIVk_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_Wf96RIVk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_Zv9NZc8J_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_9lY1MYXo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  sVarf_onMessage(_c, &Context(_c)->sVarf_WYAoUNxZ, m);
}

void Heavy_WSTD_DLAY::cBinop_qfMccuvj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MULTIPLY, 6.28319f, 0, m, &cBinop_oRKOtsno_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_oRKOtsno_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_8qIJ5wJf, HV_BINOP_DIVIDE, 0, m, &cBinop_8qIJ5wJf_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_8qIJ5wJf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_h656UThi_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cMsg_lVCYQPBV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_ySN3MIY0, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_dxG6eRFP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_OnPWhkR2, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_z1v06OoX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_aWK9v4wZ, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_7mxcJzv1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Wusx0DzF, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_9x4ghFxU_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_6VHhC3AB, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_PdI1pyAj_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_fbYsDjOX, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_gUfYDEvR_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Dc1lraeP, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_vyLzZ4px_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QphoXbAb, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Iq5ZjUSf_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_Oq7NfQBN, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_XpukBOdn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_RqvnsIAI, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_Gp5dnitZ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_QUG5OGwO, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_IPI3yMR5_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setElementToFrom(m, 0, n, 0);
  msg_setFloat(m, 1, 100.0f);
  sLine_onMessage(_c, &Context(_c)->sLine_lK5HD1uP, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cVar_uQqYvqn9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_WAmvr5TL_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_EQ, 0.0f, 0, m, &cBinop_QIKQ4o3k_sendMessage);
  cBinop_k_onMessage(_c, NULL, HV_BINOP_GREATER_THAN, 0.0f, 0, m, &cBinop_pfJZWIYo_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_WAmvr5TL_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uQqYvqn9, 1, m, &cVar_uQqYvqn9_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_TOtK2D17_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_rSe2n52Z, 0, m, &cVar_rSe2n52Z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cIf_hbZvpCMt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_rSe2n52Z, 0, m, &cVar_rSe2n52Z_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_Q4wGuM7q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hbZvpCMt, 0, m, &cIf_hbZvpCMt_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_IpFIC0eE_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TOtK2D17, 0, m, &cIf_TOtK2D17_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Nxo8MWfo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jKgTl8X0, HV_BINOP_DIVIDE, 0, m, &cBinop_jKgTl8X0_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_Gl7Hq3Xr_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AVPSljh0, HV_BINOP_MULTIPLY, 1, m, &cBinop_AVPSljh0_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_QmP3QXLO_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0xFFFFFFFF: { // "bang"
      cSlice_onMessage(_c, &Context(_c)->cSlice_7i4VcadT, 0, m, &cSlice_7i4VcadT_sendMessage);
      break;
    }
    case 0x3E004DAB: { // "set"
      cSlice_onMessage(_c, &Context(_c)->cSlice_XoLpHKMB, 0, m, &cSlice_XoLpHKMB_sendMessage);
      break;
    }
    default: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_Zy4VymEt_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_hiidtS3s_sendMessage);
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cSlice_7i4VcadT_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cVar_onMessage(_c, &Context(_c)->cVar_oWX7rJOV, 0, m, &cVar_oWX7rJOV_sendMessage);
      break;
    }
    case 1: {
      cVar_onMessage(_c, &Context(_c)->cVar_oWX7rJOV, 0, m, &cVar_oWX7rJOV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cSlice_XoLpHKMB_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_aUW9f4wJ, HV_BINOP_NEQ, 1, m, &cBinop_aUW9f4wJ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_oWX7rJOV, 1, m, &cVar_oWX7rJOV_sendMessage);
      break;
    }
    case 1: {
      cBinop_onMessage(_c, &Context(_c)->cBinop_aUW9f4wJ, HV_BINOP_NEQ, 1, m, &cBinop_aUW9f4wJ_sendMessage);
      cVar_onMessage(_c, &Context(_c)->cVar_oWX7rJOV, 1, m, &cVar_oWX7rJOV_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cVar_oWX7rJOV_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 5000.0f, 0, m, &cBinop_GHlbUMrt_sendMessage);
}

void Heavy_WSTD_DLAY::cIf_h05RrBQl_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  switch (letIn) {
    case 0: {
      break;
    }
    case 1: {
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_HOZ92eUG_sendMessage);
      cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_DOoqJHeW_sendMessage);
      break;
    }
    default: return;
  }
}

void Heavy_WSTD_DLAY::cCast_DOoqJHeW_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_oWX7rJOV, 0, m, &cVar_oWX7rJOV_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_HOZ92eUG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUW9f4wJ, HV_BINOP_NEQ, 1, m, &cBinop_aUW9f4wJ_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_aUW9f4wJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h05RrBQl, 1, m, &cIf_h05RrBQl_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_hiidtS3s_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_h05RrBQl, 0, m, &cIf_h05RrBQl_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_Zy4VymEt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_aUW9f4wJ, HV_BINOP_NEQ, 0, m, &cBinop_aUW9f4wJ_sendMessage);
}

void Heavy_WSTD_DLAY::cVar_X1j4Duy2_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_eYEJXvKm_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_4P7qgY7D_sendMessage);
}

void Heavy_WSTD_DLAY::cSwitchcase_hrs9Pc8o_onMessage(HeavyContextInterface *_c, void *o, int letIn, const HvMessage *const m, void *sendMessage) {
  int msgIndex = 0;
  switch (msg_getHash(m, msgIndex)) {
    case 0x6D60E6E: { // "symbol"
      msgIndex = 1;
      break;
    }
  }
  switch (msg_getHash(m, msgIndex)) {
    case 0x0: { // "0.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_gff4Mgqb_sendMessage);
      break;
    }
    case 0x3F800000: { // "1.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_kX50bMUt_sendMessage);
      break;
    }
    case 0x40000000: { // "2.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_LgMyNncG_sendMessage);
      break;
    }
    case 0x40400000: { // "3.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_FKIECzEd_sendMessage);
      break;
    }
    case 0x40800000: { // "4.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_D8KdXuQm_sendMessage);
      break;
    }
    case 0x40A00000: { // "5.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_RwHe2heF_sendMessage);
      break;
    }
    case 0x40C00000: { // "6.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_slg0MLvC_sendMessage);
      break;
    }
    case 0x40E00000: { // "7.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_M5PS6u1g_sendMessage);
      break;
    }
    case 0x41000000: { // "8.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_V2Bc3ZCs_sendMessage);
      break;
    }
    case 0x41100000: { // "9.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_PuWb3ICn_sendMessage);
      break;
    }
    case 0x41200000: { // "10.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_EZO5ZW2v_sendMessage);
      break;
    }
    case 0x41300000: { // "11.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_CEgb74sk_sendMessage);
      break;
    }
    case 0x41400000: { // "12.0"
      cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_SXisVOPh_sendMessage);
      break;
    }
    default: {
      break;
    }
  }
}

void Heavy_WSTD_DLAY::cCast_gff4Mgqb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_20kALcDc_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_kX50bMUt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_v4oSHlHD_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_LgMyNncG_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_3WligLxx_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_FKIECzEd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_GKcEi77O_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_D8KdXuQm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ALodUirs_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_RwHe2heF_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_2WJyEN8q_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_slg0MLvC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_fh5u2WLp_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_M5PS6u1g_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_4vFIHRhz_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_V2Bc3ZCs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_pacpqZ2k_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_PuWb3ICn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_SA0ZzHyX_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_EZO5ZW2v_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_vNN3agy0_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_CEgb74sk_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_ErhYt4uv_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cCast_SXisVOPh_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_OBgCwQXS_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cBinop_jKgTl8X0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_AVPSljh0, HV_BINOP_MULTIPLY, 0, m, &cBinop_AVPSljh0_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_AVPSljh0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_QmP3QXLO_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cCast_4P7qgY7D_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Nxo8MWfo, 0, m, &cVar_Nxo8MWfo_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Gl7Hq3Xr, 0, m, &cVar_Gl7Hq3Xr_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_eYEJXvKm_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_onMessage(_c, &Context(_c)->cBinop_jKgTl8X0, HV_BINOP_DIVIDE, 1, m, &cBinop_jKgTl8X0_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_oNLuY6WC_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Nxo8MWfo, 0, m, &cVar_Nxo8MWfo_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_zQ1cFvy4_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Gl7Hq3Xr, 0, m, &cVar_Gl7Hq3Xr_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_20kALcDc_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.166667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_v4oSHlHD_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.2f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_3WligLxx_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.25f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_GKcEi77O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.333333f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ALodUirs_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.6f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_2WJyEN8q_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 0.666667f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_fh5u2WLp_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_4vFIHRhz_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 1.5f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_pacpqZ2k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 2.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_SA0ZzHyX_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 3.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_vNN3agy0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 4.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_ErhYt4uv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 5.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_OBgCwQXS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(1);
  msg_init(m, 1, msg_getTimestamp(n));
  msg_setFloat(m, 0, 6.0f);
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_zQ1cFvy4_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oNLuY6WC_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_rW9JdECd_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "mix");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mRJJCoQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_D30otQYn_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "feedback");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mRJJCoQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_bMf7Zvz8_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_KgPXFbDE, 0, m, &cVar_KgPXFbDE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_mWoyLmqg_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_9Oc4gaK3, 0, m, &cVar_9Oc4gaK3_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_XdP0ACE9_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_rK1VHM16, 0, m, &cVar_rK1VHM16_sendMessage);
}

void Heavy_WSTD_DLAY::cMsg_GVpcAM3N_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "time");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mRJJCoQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cMsg_4QLoZ8F6_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *const n) {
  HvMessage *m = nullptr;
  m = HV_MESSAGE_ON_STACK(2);
  msg_init(m, 2, msg_getTimestamp(n));
  msg_setSymbol(m, 0, "cross");
  msg_setElementToFrom(m, 1, n, 0);
  cSwitchcase_mRJJCoQW_onMessage(_c, NULL, 0, m, NULL);
}

void Heavy_WSTD_DLAY::cBinop_GHlbUMrt_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IpFIC0eE, 0, m, &cVar_IpFIC0eE_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_pfJZWIYo_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_H8H2gOC0_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_oD07o3dP_sendMessage);
}

void Heavy_WSTD_DLAY::cBinop_QIKQ4o3k_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cCast_onMessage(_c, HV_CAST_FLOAT, 0, m, &cCast_WXImHz43_sendMessage);
  cCast_onMessage(_c, HV_CAST_BANG, 0, m, &cCast_jZ2CDYJK_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_jZ2CDYJK_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q4wGuM7q, 0, m, &cVar_Q4wGuM7q_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_WXImHz43_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_hbZvpCMt, 1, m, &cIf_hbZvpCMt_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_H8H2gOC0_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cIf_onMessage(_c, &Context(_c)->cIf_TOtK2D17, 1, m, &cIf_TOtK2D17_sendMessage);
}

void Heavy_WSTD_DLAY::cCast_oD07o3dP_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_IpFIC0eE, 0, m, &cVar_IpFIC0eE_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_XG0WzVy1_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_bMf7Zvz8_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_9ffXVyp7_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_mWoyLmqg_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_oE5fEXKS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_DIVIDE, 100.0f, 0, m, &cBinop_XdP0ACE9_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_yqUiqYLH_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_Q4wGuM7q, 0, m, &cVar_Q4wGuM7q_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_o1foEvXv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Iq5ZjUSf_sendMessage(_c, 0, m);
  cMsg_XpukBOdn_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_SfhjSkND_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cMsg_Gp5dnitZ_sendMessage(_c, 0, m);
  cMsg_IPI3yMR5_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_3DS2kO22_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_RBy2HeNM_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_BdJB8Rkb_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_l7ZkfGY6, 0, m, &cVar_l7ZkfGY6_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_nd6uL5Fh, 0, m, &cVar_nd6uL5Fh_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_Xq6N6KVs, 0, m, &cVar_Xq6N6KVs_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_03BwVQVy, 0, m, &cVar_03BwVQVy_sendMessage);
  cMsg_1z0fnGOW_sendMessage(_c, 0, m);
  cMsg_084tj0Aq_sendMessage(_c, 0, m);
  cMsg_LMoRpsrY_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_3wxlOZ8w, 0, m, &cVar_3wxlOZ8w_sendMessage);
  cMsg_SfGHl584_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_Kc9DHmmL, 0, m, &cVar_Kc9DHmmL_sendMessage);
  cMsg_Im8Xyj6G_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_1vGLPieS, 0, m, &cVar_1vGLPieS_sendMessage);
  cMsg_IpcRjbHw_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_EkdYf1OI, 0, m, &cVar_EkdYf1OI_sendMessage);
  cMsg_IWOeE88A_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_spS7S1gQ, 0, m, &cVar_spS7S1gQ_sendMessage);
  cMsg_Q6Cbq8qq_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_bNYo9qlk, 0, m, &cVar_bNYo9qlk_sendMessage);
  cVar_onMessage(_c, &Context(_c)->cVar_UNrpeEcJ, 0, m, &cVar_UNrpeEcJ_sendMessage);
  cMsg_r0BCw8tc_sendMessage(_c, 0, m);
  cVar_onMessage(_c, &Context(_c)->cVar_tgfwhqpu, 0, m, &cVar_tgfwhqpu_sendMessage);
  cMsg_Xuqewkds_sendMessage(_c, 0, m);
}

void Heavy_WSTD_DLAY::cReceive_V6AktjDv_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cBinop_k_onMessage(_c, NULL, HV_BINOP_MIN, 1.0f, 0, m, &cBinop_CnjBQmU5_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_vchNECxJ_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_uQqYvqn9, 0, m, &cVar_uQqYvqn9_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_4zhuenLS_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cVar_onMessage(_c, &Context(_c)->cVar_X1j4Duy2, 0, m, &cVar_X1j4Duy2_sendMessage);
}

void Heavy_WSTD_DLAY::cReceive_xyol7U4O_sendMessage(HeavyContextInterface *_c, int letIn, const HvMessage *m) {
  cSwitchcase_hrs9Pc8o_onMessage(_c, NULL, 0, m, NULL);
}




/*
 * Context Process Implementation
 */

int Heavy_WSTD_DLAY::process(float **inputBuffers, float **outputBuffers, int n) {
  while (hLp_hasData(&inQueue)) {
    hv_uint32_t numBytes = 0;
    ReceiverMessagePair *p = reinterpret_cast<ReceiverMessagePair *>(hLp_getReadBuffer(&inQueue, &numBytes));
    hv_assert(numBytes >= sizeof(ReceiverMessagePair));
    scheduleMessageForReceiver(p->receiverHash, &p->msg);
    hLp_consume(&inQueue);
  }

  sendBangToReceiver(0xDD21C0EB); // send to __hv_bang~ on next cycle
  const int n4 = n & ~HV_N_SIMD_MASK; // ensure that the block size is a multiple of HV_N_SIMD

  // temporary signal vars
  hv_bufferf_t Bf0, Bf1, Bf2, Bf3, Bf4, Bf5, Bf6;
  hv_bufferi_t Bi0, Bi1;

  // input and output vars
  hv_bufferf_t O0, O1;
  hv_bufferf_t I0, I1;

  // declare and init the zero buffer
  hv_bufferf_t ZERO; __hv_zero_f(VOf(ZERO));

  hv_uint32_t nextBlock = blockStartTimestamp;
  for (int n = 0; n < n4; n += HV_N_SIMD) {

    // process all of the messages for this block
    nextBlock += HV_N_SIMD;
    while (mq_hasMessageBefore(&mq, nextBlock)) {
      MessageNode *const node = mq_peek(&mq);
      node->sendMessage(this, node->let, node->m);
      mq_pop(&mq);
    }

    // load input buffers
    __hv_load_f(inputBuffers[0]+n, VOf(I0));
    __hv_load_f(inputBuffers[1]+n, VOf(I1));

    // zero output buffers
    __hv_zero_f(VOf(O0));
    __hv_zero_f(VOf(O1));

    // process all signal functions
    __hv_line_f(&sLine_OnPWhkR2, VOf(Bf0));
    __hv_line_f(&sLine_Oq7NfQBN, VOf(Bf1));
    __hv_tabhead_f(&sTabhead_CoGLviVA, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf3), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_varread_f(&sVarf_SNZSPAjg, VOf(Bf2));
    __hv_mul_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_CbiieDnN, VOf(Bf1));
    __hv_min_f(VIf(Bf2), VIf(Bf1), VOf(Bf1));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf1), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf3), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf3));
    __hv_varread_f(&sVarf_bxUwvGRm, VOf(Bf1));
    __hv_zero_f(VOf(Bf4));
    __hv_lt_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_and_f(VIf(Bf1), VIf(Bf4), VOf(Bf4));
    __hv_add_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_cast_fi(VIf(Bf4), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_9aaYFynR, VIi(Bi1), VOf(Bf4));
    __hv_tabread_if(&sTabread_q3oyyX6w, VIi(Bi0), VOf(Bf1));
    __hv_sub_f(VIf(Bf4), VIf(Bf1), VOf(Bf4));
    __hv_sub_f(VIf(Bf2), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(Bf4), VIf(Bf3), VIf(Bf1), VOf(Bf1));
    __hv_var_k_f(VOf(Bf3), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf1), VIf(Bf3), VOf(Bf3));
    __hv_var_k_f(VOf(Bf4), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf3), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_ySN3MIY0, VOf(Bf3));
    __hv_mul_f(VIf(Bf4), VIf(Bf3), VOf(Bf3));
    __hv_fma_f(VIf(I0), VIf(Bf0), VIf(Bf3), VOf(Bf3));
    __hv_line_f(&sLine_aWK9v4wZ, VOf(Bf0));
    __hv_line_f(&sLine_RqvnsIAI, VOf(Bf4));
    __hv_tabhead_f(&sTabhead_Iq6c7vjK, VOf(Bf2));
    __hv_var_k_f_r(VOf(Bf5), -1.0f, -2.0f, -3.0f, -4.0f, -5.0f, -6.0f, -7.0f, -8.0f);
    __hv_add_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_Qm0kjqfM, VOf(Bf2));
    __hv_mul_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_varread_f(&sVarf_bpjiHenw, VOf(Bf4));
    __hv_min_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_zero_f(VOf(Bf2));
    __hv_max_f(VIf(Bf4), VIf(Bf2), VOf(Bf2));
    __hv_sub_f(VIf(Bf5), VIf(Bf2), VOf(Bf2));
    __hv_floor_f(VIf(Bf2), VOf(Bf5));
    __hv_varread_f(&sVarf_wyPSfn3h, VOf(Bf4));
    __hv_zero_f(VOf(Bf6));
    __hv_lt_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_and_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_add_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_cast_fi(VIf(Bf6), VOi(Bi0));
    __hv_var_k_i(VOi(Bi1), 1, 1, 1, 1, 1, 1, 1, 1);
    __hv_add_i(VIi(Bi0), VIi(Bi1), VOi(Bi1));
    __hv_tabread_if(&sTabread_tuvlnPZU, VIi(Bi1), VOf(Bf6));
    __hv_tabread_if(&sTabread_FVyPzYH4, VIi(Bi0), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf6));
    __hv_sub_f(VIf(Bf2), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(Bf6), VIf(Bf5), VIf(Bf4), VOf(Bf4));
    __hv_var_k_f(VOf(Bf5), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_min_f(VIf(Bf4), VIf(Bf5), VOf(Bf5));
    __hv_var_k_f(VOf(Bf6), -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f, -1.0f);
    __hv_max_f(VIf(Bf5), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_Wusx0DzF, VOf(Bf5));
    __hv_mul_f(VIf(Bf6), VIf(Bf5), VOf(Bf5));
    __hv_fma_f(VIf(I1), VIf(Bf0), VIf(Bf5), VOf(Bf5));
    __hv_varread_f(&sVarf_vL7A4YK4, VOf(Bf0));
    __hv_add_f(VIf(I0), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_fkpWOmCs, VIf(Bf0));
    __hv_varread_f(&sVarf_J5qzPAbM, VOf(Bf0));
    __hv_add_f(VIf(I1), VIf(Bf0), VOf(Bf0));
    __hv_tabwrite_f(&sTabwrite_09m8jtok, VIf(Bf0));
    __hv_varread_f(&sVarf_etRbVuuc, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_4SlWMGHh, VOf(Bf1));
    __hv_rpole_f(&sRPole_8Nnfwqd6, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_UXwHHZR9, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_varread_f(&sVarf_eRruzhGI, VOf(Bf1));
    __hv_rpole_f(&sRPole_gS2ZP55h, VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_tRAndOq8, VOf(Bf0));
    __hv_rpole_f(&sRPole_VASGJz3P, VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_var_k_f(VOf(Bf1), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_agxH38lZ, VIf(Bf0), VOf(Bf6));
    __hv_mul_f(VIf(Bf6), VIf(Bf1), VOf(Bf1));
    __hv_sub_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_varread_f(&sVarf_2Wod2iJR, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_line_f(&sLine_QUG5OGwO, VOf(Bf1));
    __hv_mul_f(VIf(Bf0), VIf(Bf1), VOf(Bf1));
    __hv_line_f(&sLine_fbYsDjOX, VOf(Bf0));
    __hv_varread_f(&sVarf_iYOgGUV8, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_fm9B44YS, VOf(Bf4));
    __hv_rpole_f(&sRPole_kF56a4OO, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Szm0R5ep, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_varread_f(&sVarf_Mq5Dqw53, VOf(Bf4));
    __hv_rpole_f(&sRPole_XMYk4rv5, VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_WYAoUNxZ, VOf(Bf6));
    __hv_rpole_f(&sRPole_INoGnglR, VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_var_k_f(VOf(Bf4), 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f, 1.0f);
    __hv_del1_f(&sDel1_7j0Af9V5, VIf(Bf6), VOf(Bf2));
    __hv_mul_f(VIf(Bf2), VIf(Bf4), VOf(Bf4));
    __hv_sub_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_varread_f(&sVarf_Q9AgGE2Y, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_line_f(&sLine_lK5HD1uP, VOf(Bf4));
    __hv_mul_f(VIf(Bf6), VIf(Bf4), VOf(Bf4));
    __hv_line_f(&sLine_6VHhC3AB, VOf(Bf6));
    __hv_mul_f(VIf(Bf4), VIf(Bf6), VOf(Bf6));
    __hv_fma_f(VIf(Bf1), VIf(Bf0), VIf(Bf6), VOf(Bf6));
    __hv_varwrite_f(&sVarf_vL7A4YK4, VIf(Bf6));
    __hv_line_f(&sLine_QphoXbAb, VOf(Bf6));
    __hv_line_f(&sLine_Dc1lraeP, VOf(Bf0));
    __hv_mul_f(VIf(Bf1), VIf(Bf0), VOf(Bf0));
    __hv_fma_f(VIf(Bf4), VIf(Bf6), VIf(Bf0), VOf(Bf0));
    __hv_varwrite_f(&sVarf_J5qzPAbM, VIf(Bf0));
    __hv_add_f(VIf(Bf3), VIf(O0), VOf(O0));
    __hv_add_f(VIf(Bf5), VIf(O1), VOf(O1));

    // save output vars to output buffer
    __hv_store_f(outputBuffers[0]+n, VIf(O0));
    __hv_store_f(outputBuffers[1]+n, VIf(O1));
  }

  blockStartTimestamp = nextBlock;

  return n4; // return the number of frames processed

}

int Heavy_WSTD_DLAY::processInline(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(!(n4 & HV_N_SIMD_MASK)); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s)
  float **const bIn = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bIn[0] = inputBuffers+(0*n4);
  bIn[1] = inputBuffers+(1*n4);

  // define the heavy output buffer for 2 channel(s)
  float **const bOut = reinterpret_cast<float **>(hv_alloca(2*sizeof(float *)));
  bOut[0] = outputBuffers+(0*n4);
  bOut[1] = outputBuffers+(1*n4);

  int n = process(bIn, bOut, n4);
  return n;
}

int Heavy_WSTD_DLAY::processInlineInterleaved(float *inputBuffers, float *outputBuffers, int n4) {
  hv_assert(n4 & ~HV_N_SIMD_MASK); // ensure that n4 is a multiple of HV_N_SIMD

  // define the heavy input buffer for 2 channel(s), uninterleave
  float *const bIn = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));
  #if HV_SIMD_SSE || HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 a = _mm_load_ps(inputBuffers+i);                // LRLR
    __m128 b = _mm_load_ps(inputBuffers+4+i);              // LRLR
    __m128 x = _mm_shuffle_ps(a, b, _MM_SHUFFLE(2,0,2,0)); // LLLL
    __m128 y = _mm_shuffle_ps(a, b, _MM_SHUFFLE(3,1,3,1)); // RRRR
    _mm_store_ps(bIn+j, x);
    _mm_store_ps(bIn+n4+j, y);
  }
  #elif HV_SIMD_NEON
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4x2_t a = vld2q_f32(inputBuffers+i); // load and uninterleave
    vst1q_f32(bIn+j, a.val[0]);
    vst1q_f32(bIn+n4+j, a.val[1]);
  }
  #else // HV_SIMD_NONE
  for (int j = 0; j < n4; ++j) {
    bIn[0*n4+j] = inputBuffers[0+2*j];
    bIn[1*n4+j] = inputBuffers[1+2*j];
  }
  #endif

  // define the heavy output buffer for 2 channel(s)
  float *const bOut = reinterpret_cast<float *>(hv_alloca(2*n4*sizeof(float)));

  int n = processInline(bIn, bOut, n4);

  // interleave the heavy output into the output buffer
  #if HV_SIMD_AVX
  for (int i = 0, j = 0; j < n4; j += 8, i += 16) {
    __m256 x = _mm256_load_ps(bOut+j);    // LLLLLLLL
    __m256 y = _mm256_load_ps(bOut+n4+j); // RRRRRRRR
    __m256 a = _mm256_unpacklo_ps(x, y);  // LRLRLRLR
    __m256 b = _mm256_unpackhi_ps(x, y);  // LRLRLRLR
    _mm256_store_ps(outputBuffers+i, a);
    _mm256_store_ps(outputBuffers+8+i, b);
  }
  #elif HV_SIMD_SSE
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    __m128 x = _mm_load_ps(bOut+j);    // LLLL
    __m128 y = _mm_load_ps(bOut+n4+j); // RRRR
    __m128 a = _mm_unpacklo_ps(x, y);  // LRLR
    __m128 b = _mm_unpackhi_ps(x, y);  // LRLR
    _mm_store_ps(outputBuffers+i, a);
    _mm_store_ps(outputBuffers+4+i, b);
  }
  #elif HV_SIMD_NEON
  // https://community.arm.com/groups/processors/blog/2012/03/13/coding-for-neon--part-5-rearranging-vectors
  for (int i = 0, j = 0; j < n4; j += 4, i += 8) {
    float32x4_t x = vld1q_f32(bOut+j);
    float32x4_t y = vld1q_f32(bOut+n4+j);
    float32x4x2_t z = {x, y};
    vst2q_f32(outputBuffers+i, z); // interleave and store
  }
  #else // HV_SIMD_NONE
  for (int i = 0; i < 2; ++i) {
    for (int j = 0; j < n4; ++j) {
      outputBuffers[i+2*j] = bOut[i*n4+j];
    }
  }
  #endif

  return n;
}
