/**
 * Copyright (c) 2025 Enzien Audio, Ltd.
 * 
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 * 
 * 1. Redistributions of source code must retain the above copyright notice,
 *    this list of conditions, and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the phrase "powered by heavy",
 *    the heavy logo, and a hyperlink to https://enzienaudio.com, all in a visible
 *    form.
 * 
 *   2.1 If the Application is distributed in a store system (for example,
 *       the Apple "App Store" or "Google Play"), the phrase "powered by heavy"
 *       shall be included in the app description or the copyright text as well as
 *       the in the app itself. The heavy logo will shall be visible in the app
 *       itself as well.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
 * FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
 * SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
 * CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 * 
 */

#ifndef _HEAVY_CONTEXT_WSTD_DLAY_HPP_
#define _HEAVY_CONTEXT_WSTD_DLAY_HPP_

// object includes
#include "HeavyContext.hpp"
#include "HvTable.h"
#include "HvSignalTabread.h"
#include "HvControlDelay.h"
#include "HvMath.h"
#include "HvControlIf.h"
#include "HvSignalDel1.h"
#include "HvControlVar.h"
#include "HvControlCast.h"
#include "HvSignalTabwrite.h"
#include "HvSignalLine.h"
#include "HvControlBinop.h"
#include "HvControlSystem.h"
#include "HvControlSlice.h"
#include "HvSignalVar.h"
#include "HvSignalRPole.h"
#include "HvControlUnop.h"

class Heavy_WSTD_DLAY : public HeavyContext {

 public:
  Heavy_WSTD_DLAY(double sampleRate, int poolKb=10, int inQueueKb=2, int outQueueKb=0);
  ~Heavy_WSTD_DLAY();

  const char *getName() override { return "WSTD_DLAY"; }
  int getNumInputChannels() override { return 2; }
  int getNumOutputChannels() override { return 2; }

  int process(float **inputBuffers, float **outputBuffer, int n) override;
  int processInline(float *inputBuffers, float *outputBuffer, int n) override;
  int processInlineInterleaved(float *inputBuffers, float *outputBuffer, int n) override;

  int getParameterInfo(int index, HvParameterInfo *info) override;
  struct Parameter {
    struct In {
      enum ParameterIn : hv_uint32_t {
        CROSS = 0xB6A8F09D, // Cross
        FEEDBACK = 0x57157946, // Feedback
        MIX = 0x97D46AC6, // Mix
        SYNC = 0x4A331B66, // Sync
        TIME = 0x58E5C2DB, // Time
        TIMESYNC = 0x49107604, // TimeSync
      };
    };
  };

 private:
  HvTable *getTableForHash(hv_uint32_t tableHash) override;
  void scheduleMessageForReceiver(hv_uint32_t receiverHash, HvMessage *m) override;

  // static sendMessage functions
  static void cVar_9Oc4gaK3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rSe2n52Z_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_rK1VHM16_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_KgPXFbDE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_lKO7Wwx0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_Ij33VXLR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_l7ZkfGY6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_NnimxFmG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_mRJJCoQW_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_3vZQKk3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_nd6uL5Fh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_VoRo4zn1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_LvCPiCRs_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7ngxj1t9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Xq6N6KVs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_DkVLW8yJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_RBy2HeNM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Fy3Gyl5K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_crsI9S8f_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cUnop_yT56nFIR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ztoA4kyI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_U1PgqJQT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_JNOSKu43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_IZQGflmf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_1Nz11jFo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_j0q2lH8V_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8R5DjZuu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_xohA3M4y_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_X38WNLb4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_CnjBQmU5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AwrTFmMb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Gjkb3VFn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_p83e03x8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_pB1qtLX1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HbmJ6rAZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ivN6H75G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9gp5gcXP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rsd7M6WK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_G1lKuHFU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JaHuFp4K_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_nwg9lQT0_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_DTPhuiSG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_03BwVQVy_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSend_cRJ3Hg0l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_1z0fnGOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_z5W9IHC3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_mbVzZfOc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_GTnphr4x_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_AQCqFuMj_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_zDH6sKOW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_buq1Ber6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QLZnZtoE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Uc2s5Zy7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_QbEit9Rm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_TF943sV4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lO6qk57E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_yIc9cE1t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_084tj0Aq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_CIdyjMs9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_aXpJ3ceg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cDelay_wiCZR0mh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_b5XZeBiD_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cBinop_MaOMk6vf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void hTable_wBMkSMgR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_urzBZG9k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ypozcDiT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fc7LRjwl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_ysWToE8Q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ngxJeCTM_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bpSIyEim_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_3wxlOZ8w_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_LMoRpsrY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ZeDYURi7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LBRz6R66_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oQ19GAGB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PpDyqVSe_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qZvrm8Q8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_z8FsJUo3_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3Iy4SIw7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Kc9DHmmL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SfGHl584_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_waz12ZVj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PQlXqOPf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_f5E30R6r_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_S8eSPrEC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NePOLU3t_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Yj1DgXot_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_PSRCfXIQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_myxnBcVn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_4MnELsFL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_1vGLPieS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Im8Xyj6G_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_ucSL0xsr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_DKpxkSXm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_3NOEV9r7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_bwA4Io7L_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yKXOHcaX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_L9yeBYom_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GlgMo1to_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Cm5HgORg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_dvY2fbfU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_r0BCw8tc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_JrW6jH6N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_UNrpeEcJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_wpJlubCa_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KQ4NIcAH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gOg6DbOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0u8jtJ3E_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Xuqewkds_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_06wR5t9o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_tgfwhqpu_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_aWbGIQwY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_eHWHAjtd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_xguWEKgG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_r1TMIPTV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_EkdYf1OI_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IpcRjbHw_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_5DGUP1pr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_c73N9gwi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bWlBU3ns_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lLkJ9qrK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_KPaUgHxV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_tAKK1CEs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_ZKBCBKEk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_spS7S1gQ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IWOeE88A_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_fOylxyMN_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_63IH9owf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_JYXYuVET_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_nRC6VO7o_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9ZyUwTdd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_LOKOg4RD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_NLYKuUnY_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Zv9NZc8J_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_yEOEzTxH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_bNYo9qlk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Q6Cbq8qq_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSystem_3tDMWDOE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_0DFXpBMX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_rZZcS90l_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_h656UThi_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_Wf96RIVk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_9lY1MYXo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_qfMccuvj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_oRKOtsno_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_8qIJ5wJf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_lVCYQPBV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_dxG6eRFP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_z1v06OoX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_7mxcJzv1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_9x4ghFxU_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_PdI1pyAj_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_gUfYDEvR_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vyLzZ4px_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Iq5ZjUSf_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_XpukBOdn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_Gp5dnitZ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_IPI3yMR5_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_uQqYvqn9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_WAmvr5TL_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_TOtK2D17_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_hbZvpCMt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Q4wGuM7q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_IpFIC0eE_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Nxo8MWfo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_Gl7Hq3Xr_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_QmP3QXLO_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cSlice_7i4VcadT_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSlice_XoLpHKMB_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_oWX7rJOV_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cIf_h05RrBQl_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_DOoqJHeW_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_HOZ92eUG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_aUW9f4wJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_hiidtS3s_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_Zy4VymEt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cVar_X1j4Duy2_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cSwitchcase_hrs9Pc8o_onMessage(HeavyContextInterface *, void *, int letIn, const HvMessage *const, void *);
  static void cCast_gff4Mgqb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_kX50bMUt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_LgMyNncG_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_FKIECzEd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_D8KdXuQm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_RwHe2heF_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_slg0MLvC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_M5PS6u1g_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_V2Bc3ZCs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_PuWb3ICn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_EZO5ZW2v_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_CEgb74sk_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_SXisVOPh_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_jKgTl8X0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_AVPSljh0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_4P7qgY7D_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_eYEJXvKm_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oNLuY6WC_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_zQ1cFvy4_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_20kALcDc_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_v4oSHlHD_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_3WligLxx_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GKcEi77O_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ALodUirs_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_2WJyEN8q_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_fh5u2WLp_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4vFIHRhz_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_pacpqZ2k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_SA0ZzHyX_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_vNN3agy0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_ErhYt4uv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_OBgCwQXS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_rW9JdECd_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_D30otQYn_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_bMf7Zvz8_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_mWoyLmqg_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_XdP0ACE9_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_GVpcAM3N_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cMsg_4QLoZ8F6_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_GHlbUMrt_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_pfJZWIYo_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cBinop_QIKQ4o3k_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_jZ2CDYJK_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_WXImHz43_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_H8H2gOC0_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cCast_oD07o3dP_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_XG0WzVy1_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_9ffXVyp7_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_oE5fEXKS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_yqUiqYLH_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_o1foEvXv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_SfhjSkND_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_3DS2kO22_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_BdJB8Rkb_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_V6AktjDv_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_vchNECxJ_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_4zhuenLS_sendMessage(HeavyContextInterface *, int, const HvMessage *);
  static void cReceive_xyol7U4O_sendMessage(HeavyContextInterface *, int, const HvMessage *);

  // objects
  SignalLine sLine_OnPWhkR2;
  SignalLine sLine_Oq7NfQBN;
  SignalTabhead sTabhead_CoGLviVA;
  SignalTabread sTabread_9aaYFynR;
  SignalTabread sTabread_q3oyyX6w;
  SignalLine sLine_ySN3MIY0;
  SignalLine sLine_aWK9v4wZ;
  SignalLine sLine_RqvnsIAI;
  SignalTabhead sTabhead_Iq6c7vjK;
  SignalTabread sTabread_tuvlnPZU;
  SignalTabread sTabread_FVyPzYH4;
  SignalLine sLine_Wusx0DzF;
  SignalTabwrite sTabwrite_fkpWOmCs;
  SignalTabwrite sTabwrite_09m8jtok;
  SignalRPole sRPole_8Nnfwqd6;
  SignalRPole sRPole_gS2ZP55h;
  SignalRPole sRPole_VASGJz3P;
  SignalDel1 sDel1_agxH38lZ;
  SignalLine sLine_QUG5OGwO;
  SignalLine sLine_fbYsDjOX;
  SignalRPole sRPole_kF56a4OO;
  SignalRPole sRPole_XMYk4rv5;
  SignalRPole sRPole_INoGnglR;
  SignalDel1 sDel1_7j0Af9V5;
  SignalLine sLine_lK5HD1uP;
  SignalLine sLine_6VHhC3AB;
  SignalLine sLine_QphoXbAb;
  SignalLine sLine_Dc1lraeP;
  ControlVar cVar_9Oc4gaK3;
  ControlVar cVar_rSe2n52Z;
  ControlVar cVar_rK1VHM16;
  ControlVar cVar_KgPXFbDE;
  ControlSlice cSlice_Ij33VXLR;
  ControlVar cVar_l7ZkfGY6;
  ControlSlice cSlice_3vZQKk3t;
  ControlVar cVar_nd6uL5Fh;
  ControlSlice cSlice_7ngxj1t9;
  ControlVar cVar_Xq6N6KVs;
  ControlBinop cBinop_RBy2HeNM;
  ControlBinop cBinop_Fy3Gyl5K;
  ControlBinop cBinop_ztoA4kyI;
  ControlBinop cBinop_U1PgqJQT;
  ControlBinop cBinop_1Nz11jFo;
  ControlBinop cBinop_8R5DjZuu;
  ControlBinop cBinop_xohA3M4y;
  ControlBinop cBinop_X38WNLb4;
  ControlBinop cBinop_CnjBQmU5;
  ControlBinop cBinop_AwrTFmMb;
  ControlBinop cBinop_Gjkb3VFn;
  ControlBinop cBinop_p83e03x8;
  ControlBinop cBinop_ivN6H75G;
  ControlBinop cBinop_rsd7M6WK;
  ControlBinop cBinop_G1lKuHFU;
  ControlBinop cBinop_JaHuFp4K;
  ControlSlice cSlice_DTPhuiSG;
  ControlVar cVar_03BwVQVy;
  ControlDelay cDelay_mbVzZfOc;
  ControlDelay cDelay_GTnphr4x;
  ControlBinop cBinop_zDH6sKOW;
  HvTable hTable_buq1Ber6;
  ControlBinop cBinop_Uc2s5Zy7;
  ControlDelay cDelay_aXpJ3ceg;
  ControlDelay cDelay_wiCZR0mh;
  ControlBinop cBinop_MaOMk6vf;
  HvTable hTable_wBMkSMgR;
  ControlBinop cBinop_ypozcDiT;
  ControlVar cVar_3wxlOZ8w;
  ControlBinop cBinop_LBRz6R66;
  ControlBinop cBinop_oQ19GAGB;
  SignalVarf sVarf_4SlWMGHh;
  ControlBinop cBinop_qZvrm8Q8;
  ControlBinop cBinop_z8FsJUo3;
  ControlBinop cBinop_3Iy4SIw7;
  SignalVarf sVarf_etRbVuuc;
  ControlVar cVar_Kc9DHmmL;
  ControlBinop cBinop_PQlXqOPf;
  ControlBinop cBinop_f5E30R6r;
  SignalVarf sVarf_eRruzhGI;
  ControlBinop cBinop_NePOLU3t;
  ControlBinop cBinop_Yj1DgXot;
  ControlBinop cBinop_PSRCfXIQ;
  SignalVarf sVarf_UXwHHZR9;
  ControlBinop cBinop_myxnBcVn;
  ControlBinop cBinop_4MnELsFL;
  SignalVarf sVarf_tRAndOq8;
  ControlVar cVar_1vGLPieS;
  ControlBinop cBinop_DKpxkSXm;
  ControlBinop cBinop_3NOEV9r7;
  ControlBinop cBinop_yKXOHcaX;
  ControlBinop cBinop_L9yeBYom;
  ControlBinop cBinop_GlgMo1to;
  ControlBinop cBinop_Cm5HgORg;
  ControlBinop cBinop_dvY2fbfU;
  SignalVarf sVarf_2Wod2iJR;
  ControlVar cVar_UNrpeEcJ;
  ControlBinop cBinop_KQ4NIcAH;
  ControlBinop cBinop_0u8jtJ3E;
  SignalVarf sVarf_bxUwvGRm;
  SignalVarf sVarf_SNZSPAjg;
  SignalVarf sVarf_CbiieDnN;
  ControlVar cVar_tgfwhqpu;
  ControlBinop cBinop_eHWHAjtd;
  ControlBinop cBinop_r1TMIPTV;
  SignalVarf sVarf_wyPSfn3h;
  SignalVarf sVarf_Qm0kjqfM;
  SignalVarf sVarf_bpjiHenw;
  ControlVar cVar_EkdYf1OI;
  ControlBinop cBinop_c73N9gwi;
  ControlBinop cBinop_bWlBU3ns;
  SignalVarf sVarf_fm9B44YS;
  ControlBinop cBinop_KPaUgHxV;
  ControlBinop cBinop_tAKK1CEs;
  ControlBinop cBinop_ZKBCBKEk;
  SignalVarf sVarf_iYOgGUV8;
  ControlVar cVar_spS7S1gQ;
  ControlBinop cBinop_63IH9owf;
  ControlBinop cBinop_JYXYuVET;
  SignalVarf sVarf_Mq5Dqw53;
  ControlBinop cBinop_9ZyUwTdd;
  ControlBinop cBinop_LOKOg4RD;
  ControlBinop cBinop_NLYKuUnY;
  SignalVarf sVarf_Szm0R5ep;
  ControlBinop cBinop_Zv9NZc8J;
  ControlBinop cBinop_yEOEzTxH;
  SignalVarf sVarf_WYAoUNxZ;
  ControlVar cVar_bNYo9qlk;
  ControlBinop cBinop_0DFXpBMX;
  ControlBinop cBinop_rZZcS90l;
  ControlBinop cBinop_Wf96RIVk;
  ControlBinop cBinop_9lY1MYXo;
  ControlBinop cBinop_qfMccuvj;
  ControlBinop cBinop_oRKOtsno;
  ControlBinop cBinop_8qIJ5wJf;
  SignalVarf sVarf_Q9AgGE2Y;
  SignalVarf sVarf_vL7A4YK4;
  SignalVarf sVarf_J5qzPAbM;
  ControlVar cVar_uQqYvqn9;
  ControlBinop cBinop_WAmvr5TL;
  ControlIf cIf_TOtK2D17;
  ControlIf cIf_hbZvpCMt;
  ControlVar cVar_Q4wGuM7q;
  ControlVar cVar_IpFIC0eE;
  ControlVar cVar_Nxo8MWfo;
  ControlVar cVar_Gl7Hq3Xr;
  ControlSlice cSlice_7i4VcadT;
  ControlSlice cSlice_XoLpHKMB;
  ControlVar cVar_oWX7rJOV;
  ControlIf cIf_h05RrBQl;
  ControlBinop cBinop_aUW9f4wJ;
  ControlVar cVar_X1j4Duy2;
  ControlBinop cBinop_jKgTl8X0;
  ControlBinop cBinop_AVPSljh0;
  ControlBinop cBinop_bMf7Zvz8;
  ControlBinop cBinop_mWoyLmqg;
  ControlBinop cBinop_XdP0ACE9;
  ControlBinop cBinop_GHlbUMrt;
  ControlBinop cBinop_pfJZWIYo;
  ControlBinop cBinop_QIKQ4o3k;
};

#endif // _HEAVY_CONTEXT_WSTD_DLAY_HPP_
